@@ -26,7 +26,7 @@
 #define M_PI    3.14159265358979323846
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 AudioTone::AudioTone(timeout_t duration, Rate r)
 {
@@ -203,4 +203,4 @@ bool AudioTone::is_silent(void)
     return false;
 }
 
-
+} // namespace ucommon
