@@ -40,10 +40,12 @@ int _w32_ccaudio_dummy = 0;
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
+namespace ucommon {
+
 extern  LONG buffer_framing;
 extern  LONG buffer_count;
 
-class W32Semaphore
+class __LOCAL W32Semaphore
 {
 private:
     HANDLE sem;
@@ -75,9 +77,7 @@ void W32Semaphore::post(void)
     ReleaseSemaphore(sem, 1, (LPLONG)NULL);
 }
 
-using namespace UCOMMON_NAMESPACE;
-
-class W32AudioDevice : public AudioDevice
+class __LOCAL W32AudioDevice : public AudioDevice
 {
 private:
     HWAVEOUT hPlay;
@@ -323,4 +323,6 @@ AudioDevice *Audio::getDevice(unsigned index, DeviceMode mode)
     return dev;
 }
 
+} // namespace ucommon
+
 #endif
